@@ -38,6 +38,7 @@ Examples
 >>> remote_device['device_type'] = best_match
 >>> connection = ConnectHandler(**remote_device)
 """
+
 from typing import Any, List, Optional, Union, Dict
 import re
 import time
@@ -94,13 +95,19 @@ SSH_MAPPER_DICT = {
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
+    "cisco_ftd": {
+        "cmd": "show version",
+        "search_patterns": [r"Cisco Firepower"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
     "cisco_ios": {
         "cmd": "show version",
         "search_patterns": [
             "Cisco IOS Software",
             "Cisco Internetwork Operating System Software",
         ],
-        "priority": 99,
+        "priority": 95,
         "dispatch": "_autodetect_std",
     },
     "cisco_xe": {
@@ -302,6 +309,12 @@ SSH_MAPPER_DICT = {
         "priority": 99,
         "dispatch": "_autodetect_std",
     },
+    "netgear_prosafe": {
+        "cmd": "show version",
+        "search_patterns": [r"ProSAFE"],
+        "priority": 99,
+        "dispatch": "_autodetect_std",
+    },
 }
 
 # Sort SSH_MAPPER_DICT such that the most common commands are first
